Package: freegroup
Type: Package
Title: The Free Group
Version: 1.2-1-1
Authors@R: c(person(c("Robin", "K. S. "), "Hankin", 
    role=c("aut","cre"),
    email="hankin.robin@gmail.com",
		comment = c(ORCID = "0000-0001-5982-0415")))
Maintainer: Robin K. S. Hankin <hankin.robin@gmail.com>
Description: The free group in R; juxtaposition is represented by a
  plus.  Includes inversion, multiplication by a scalar,
  group-theoretic power operation, and Tietze forms.  To cite the
  package in publications please use Hankin (2022)
  <doi:10.48550/ARXIV.2212.05883>.
Depends: R (>= 4.1.0)
Suggests: knitr, rmarkdown, permutations, testthat, covr
LazyData: yes
Imports: freealg (>= 1.0-4), magic (>= 1.5-9), magrittr, methods, plyr
VignetteBuilder: knitr
License: GPL-2
URL: https://github.com/RobinHankin/freegroup,
        https://robinhankin.github.io/freegroup/
BugReports: https://github.com/RobinHankin/freegroup/issues
RoxygenNote: 7.3.3
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2026-08-21 18:14:03 UTC; rhankin
Author: Robin K. S. Hankin [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-5982-0415>)
Repository: CRAN
Date/Publication: 2026-08-21 21:50:02 UTC
