exportPattern("^[[:alpha:]]+")

import("magrittr")
import("methods")

importFrom("magic","shift")
importFrom("plyr","alply")
importFrom("utils", "tail")

importClassesFrom("freealg", "dot")
importMethodsFrom("freealg", "[")

export("%~%")

S3method("%~%", free)

S3method("[", free)
S3method("[<-", free)
S3method("c", free)
S3method("print", free)

S3method("Ops",free)
S3method("rep",free)

S3method("inverse",free)
S3method("inverse",matrix)
S3method("sum" , free)
S3method("cumsum" , free)

S3method("tietze",free)
S3method("tietze",matrix)

S3method("is.id",free)
S3method("is.conjugate",free)

S3method("abs", free)
