\name{Extract}
\alias{Extract.free}
\alias{[.free}
\alias{[<-.free}
\title{Extract or replace parts of a free group object}
\description{Extract or replace subsets of free objects}
\usage{
\method{[}{free}(x, ...)
\method{[}{free}(x, index) <-  value
}
\arguments{
  \item{x}{Object of class \code{free}}
  \item{index}{elements to extract or replace}
  \item{value}{replacement value}
  \item{...}{Elements to extract}
}
\details{
These methods (should) work as expected: an object of class
\code{free} is a list but standard extraction techniques should work.
}
\note{
  Extraction by \code{NA} is not implemented.
}
\examples{

(x <- rfree(20,8,8))

x[5:6]
x[1:2]  <- -x[11:12]

x[1:5] <- keep(x[1:5],1:3)

}
